pub async fn evaluate(server_id: &str) -> Result<McpManagerOutput, AppError>Expand description
Fetch detailed information about a single registry server and generate a concrete install recommendation for the agent to present to the user.
pub async fn evaluate(server_id: &str) -> Result<McpManagerOutput, AppError>Fetch detailed information about a single registry server and generate a concrete install recommendation for the agent to present to the user.